@@ -8,16 +8,22 @@
  */
 
 package org.gnu.gnome;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 /**
  *
  */
 public class CanvasBpath extends CanvasShape {
+
+	public CanvasBpath(CanvasGroup group) {
+		super(group, gnome_canvas_bpath_get_type());
+	}
+	
 	/**
 	 * Constructs an instance of CanvasBpath from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasBpath(int handle) {
+	CanvasBpath(Handle handle) {
 		super(handle);
 	}
 
@@ -28,11 +34,7 @@ public class CanvasBpath extends CanvasShape {
 		return new Type(gnome_canvas_bpath_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_canvas_bpath_get_type();
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+
 }
