@@ -13,6 +13,7 @@ import java.util.Vector;
 
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.DruidPageChangeEvent;
 import org.gnu.gnome.event.DruidPageChangeListener;
@@ -41,7 +42,7 @@ public class DruidPage extends Bin {
 	 * Constructs a new DruidPage object form a native resource.
 	 * @param handle The handle to the native resource.
 	 */
-	public DruidPage(int handle) {
+	public DruidPage(Handle handle) {
 		super(handle);
 	}
 
@@ -194,17 +195,13 @@ public class DruidPage extends Bin {
 		anEvtMap.addEvent("prepare", "handlePrepare", DruidPageSetupEvent.Type.PREPARE, DruidPageSetupListener.class);
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_druid_page_get_type();
-	native static final protected int gnome_druid_page_new();
-	native static final protected boolean gnome_druid_page_next(int page);
-	native static final protected void gnome_druid_page_prepare(int page);
-	native static final protected boolean gnome_druid_page_back(int page);
-	native static final protected boolean gnome_druid_page_cancel(int page);
-	native static final protected void gnome_druid_page_finish(int page);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_druid_page_new();
+	native static final protected boolean gnome_druid_page_next(Handle page);
+	native static final protected void gnome_druid_page_prepare(Handle page);
+	native static final protected boolean gnome_druid_page_back(Handle page);
+	native static final protected boolean gnome_druid_page_cancel(Handle page);
+	native static final protected void gnome_druid_page_finish(Handle page);
+
 }
