@@ -9,12 +9,15 @@
 
 package org.gnu.gnome;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.VBox;
 /**
  * This widget provides an entry box with history and a button which can pop up a
  * file selector dialog box.  It also accepts DND drops from the filemanager and 
  * other sources.
+ * 
+ * @deprecated
  */
 public class FileEntry extends VBox {
 	/**
@@ -27,7 +30,7 @@ public class FileEntry extends VBox {
 	/**
 	 * Construct a new FileEntry from a handle to a native resource.
 	 */
-	public FileEntry(int handle) {
+	public FileEntry(Handle handle) {
 	    super(handle);
 	}
 	
@@ -35,7 +38,7 @@ public class FileEntry extends VBox {
 	 * Returns the Gnome Entry widget.
 	 */
 	public Entry getEntry() {
-		int hndl = gnome_file_entry_gnome_entry(getHandle());
+		Handle hndl = gnome_file_entry_gnome_entry(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (Entry)obj;
@@ -91,22 +94,18 @@ public class FileEntry extends VBox {
 		return new Type(gnome_file_entry_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_file_entry_get_type();
-	native static final protected int gnome_file_entry_new(String historyId, String browseDialogTitle);
-	native static final protected int gnome_file_entry_gnome_entry(int fentry);
-	native static final protected int gnome_file_entry_gtk_entry(int fentry);
-	native static final protected void gnome_file_entry_set_title(int fentry, String browseDialogTitle);
-	native static final protected void gnome_file_entry_set_default_path(int fentry, String path);
-	native static final protected void gnome_file_entry_set_directory_entry(int fentry, boolean directoryEntry);
-	native static final protected boolean gnome_file_entry_get_directory_entry(int fentry);
-	native static final protected String gnome_file_entry_get_full_path(int fentry, boolean fileMustExist);
-	native static final protected void gnome_file_entry_set_filename(int fentry, String filename);
-	native static final protected void gnome_file_entry_set_modal(int fentry, boolean isModal);
-	native static final protected boolean gnome_file_entry_get_modal(int fentry);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_file_entry_new(String historyId, String browseDialogTitle);
+	native static final protected Handle gnome_file_entry_gnome_entry(Handle fentry);
+	native static final protected Handle gnome_file_entry_gtk_entry(Handle fentry);
+	native static final protected void gnome_file_entry_set_title(Handle fentry, String browseDialogTitle);
+	native static final protected void gnome_file_entry_set_default_path(Handle fentry, String path);
+	native static final protected void gnome_file_entry_set_directory_entry(Handle fentry, boolean directoryEntry);
+	native static final protected boolean gnome_file_entry_get_directory_entry(Handle fentry);
+	native static final protected String gnome_file_entry_get_full_path(Handle fentry, boolean fileMustExist);
+	native static final protected void gnome_file_entry_set_filename(Handle fentry, String filename);
+	native static final protected void gnome_file_entry_set_modal(Handle fentry, boolean isModal);
+	native static final protected boolean gnome_file_entry_get_modal(Handle fentry);
+
 }
