@@ -10,7 +10,8 @@
 package org.gnu.gnome;
 
 import org.gnu.gdk.ModifierType;
-import org.gnu.glib.GObject;
+import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
 import org.gnu.gtk.GtkStockItem;
 import org.gnu.gtk.Widget;
 import org.gnu.gtk.event.ButtonEvent;
@@ -20,7 +21,7 @@ import org.gnu.gtk.event.MenuItemListener;
 /**
  *
  */
-public class UIInfo extends GObject {
+public class UIInfo extends Boxed {
 
 	public int getType() {
 		return getType(getHandle());
@@ -49,7 +50,7 @@ public class UIInfo extends GObject {
 		super(init(type, label, hint, pixmapType, acceleratorKey, acMods));
 		if (moreInfo == null)
 			return;
-		int[] hndls = new int[moreInfo.length];
+		Handle[] hndls = new Handle[moreInfo.length];
 		for (int i = 0; i < moreInfo.length; i++) 
 			hndls[i] = moreInfo[i].getHandle();
 		if (null != hndls)
@@ -67,7 +68,7 @@ public class UIInfo extends GObject {
 	*/
 	protected UIInfo(UIInfoType type, String label, String hint, UIInfo[] moreInfo, UIPixmapType pixmapType, byte data[], int acceleratorKey, ModifierType acMods) {
 		super(init(type, label, hint, pixmapType, acceleratorKey, acMods));
-		int[] hndls = null;
+		Handle[] hndls = null;
 		for (int i = 0; i < moreInfo.length; i++) 
 			hndls[i] = moreInfo[i].getHandle();
 		if (null != hndls)
@@ -149,11 +150,11 @@ public class UIInfo extends GObject {
 		setPixmapInfo(getHandle(), data);
 	}
 
-	protected UIInfo(int hndl) {
-		setHandle(hndl);
+	protected UIInfo(Handle hndl) {
+		super(hndl);
 	}
 	
-	private static int init(UIInfoType type, String label, String hint, UIPixmapType pixmapType, int acceleratorKey, ModifierType acMods) {
+	private static Handle init(UIInfoType type, String label, String hint, UIPixmapType pixmapType, int acceleratorKey, ModifierType acMods) {
 	    if (null == acMods) {
 			acMods = ModifierType.intern(0);
 	    }
@@ -169,8 +170,8 @@ public class UIInfo extends GObject {
 	}
 
 	public Widget getWidget(){
-		int hndl = getWidget(getHandle());
-		if (0 == hndl)
+		Handle hndl = getWidget(getHandle());
+		if (null == hndl)
 			return null;
 		return new Widget(hndl);
 	}
@@ -635,28 +636,23 @@ public class UIInfo extends GObject {
 //
 //	}
 	
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
-	native static final protected int getType(int cptr);
-	native static final protected String getLabel(int cptr);
-	native static final protected String getHint(int cptr);
-	native static final protected int getMoreinfo(int cptr);
-	native static final protected int getUserData(int cptr);
-	native static final protected int getPixmapType(int cptr);
-	native static final protected int getPixmapInfo(int cptr);
-	native static final protected int getAcceleratorKey(int cptr);
-	native static final protected int getAcMods(int cptr);
-	native static final protected int getWidget(int cptr);
 
-	native static final protected int[] toNativeArray( int[] handles );
-	native static final protected int uiinfo_new(int type, String label, String hint, int pixmapType, int acceleratorKey, int acMods);
-	native static final protected void setPixmapInfo(int handle, String name);
-	native static final protected void setPixmapInfo(int handle, byte[] data);
-	native static final protected void setCallbackInfo(int handle, String callbackFunc, Object callbackObj);
-	native static final protected void setMoreInfo(int handle, String moreInfo);
-	native static final protected void setSubmenuInfo(int handle, int[] moreInfo);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected int getType(Handle cptr);
+	native static final protected String getLabel(Handle cptr);
+	native static final protected String getHint(Handle cptr);
+	native static final protected int getMoreinfo(Handle cptr);
+	native static final protected int getUserData(Handle cptr);
+	native static final protected int getPixmapType(Handle cptr);
+	native static final protected int getPixmapInfo(Handle cptr);
+	native static final protected int getAcceleratorKey(Handle cptr);
+	native static final protected int getAcMods(Handle cptr);
+	native static final protected Handle getWidget(Handle cptr);
+
+	native static final protected Handle uiinfo_new(int type, String label, String hint, int pixmapType, int acceleratorKey, int acMods);
+	native static final protected void setPixmapInfo(Handle handle, String name);
+	native static final protected void setPixmapInfo(Handle handle, byte[] data);
+	native static final protected void setCallbackInfo(Handle handle, String callbackFunc, Object callbackObj);
+	native static final protected void setMoreInfo(Handle handle, String moreInfo);
+	native static final protected void setSubmenuInfo(Handle handle, Handle[] moreInfo);
+
 }
